get_immig_rate: Calculate immigration rate

Description Usage Arguments Author(s) References See Also

Description

Internal function. Calculates the immigration rate given the current number of species in the system, the carrying capacity

Usage

1
2
get_immig_rate(timeval, totaltime, gam, Apars, divdep, island_ontogeny,
  sea_level, island_spec, K, mainland_n)

Arguments

timeval

current time of simulation

totaltime

total time of simulation

gam

per capita immigration rate

Apars

a named list containing area parameters as created by create_area_params:

  • [1]: maximum area

  • [2]: value from 0 to 1 indicating where in the island's history the peak area is achieved

  • [3]: sharpness of peak

  • [4]: total island age

island_ontogeny

a string describing the type of island ontogeny. Can be NULL, "beta" for a beta function describing area through time, or "linear" for a linear function

island_spec

matrix with current state of system

K

carrying capacity

mainland_n

total number of species present in the mainland

Author(s)

Pedro Neves

References

Valente, Luis M., Rampal S. Etienne, and Albert B. Phillimore. "The effects of island ontogeny on species diversity and phylogeny." Proceedings of the Royal Society of London B: Biological Sciences 281.1784 (2014): 20133227.

See Also

Does the same as DAISIE_calc_clade_imm_rate

Other rates calculation: get_ana_rate, get_ext_rate, get_t_hor, island_area, update_rates


joshwlambert/DAISIEsim documentation built on June 5, 2019, 7:58 a.m.